$TITLE:'REFRACTIVITY OF AIR'
$SUBTITLE:'REFRACTIVITY'
      FUNCTION AIRRI ( TC, PMB, RH )
C
C        REFRACTIVTY OF AIR
C        REF. INDEX  = 1 + 10**6 * RI
C
C      -------------------------------------------------
C      J.R. Clynch   6/30/92  NPS
C
C      From notes of K. Davidson Met.
C
C      Checked with CRC handbook on Vapor Pressure H2O
C      and a Marwin Radiosonde Raw data set
C
C       Agrees with both to .2 percent
C       -------------------------------------------------
C
C
C    MODHIST:
C
C
C
C    INPUT
C              TC   R*8       TEMP. DEG C
C              PMB  R*8       PRESSURE MILLI-BARS
C              RH   R*8       RELATIVE HUMIDITY
C
C    OUTPUT    FUNCTION VALUE R*8  REFRACTIVITY
C
C
$INCLUDE:'WRDSIZ.INC'
C
C
      DATA  TZERO     / 273.2 D0 /
      DATA  CAIR      / 77.6  D0 /
      DATA  C1H2O     / -5.6  D0 /
      DATA  C2H2O     / 3.75  D5  /
C
C        -------------------------------------------------
C
      TK  = TC + TZERO
C
C           GET PARTIAL PRESSURE WATER = RH*VAPOR PRESSURE
C
      EH2O = 0.0D0
      IF ( RH.GT.0.0D0 ) EH2O  = RH * PPH2O ( TC ) / 100.0D0
C
      RI  =  CAIR * (PMB/TK) - C1H2O*(EH2O/TK) + C2H2O*(EH2O/TK/TK)
C
      AIRRI  =  RI
C
      RETURN
      END
$PAGE
$SUBTITLE:'SAT. VAPOR PRES WATER'
      FUNCTION PPH2O ( TC )
C
C        PARTIAL PRESSURE H2O AT GIVEN TEMP.  IN DEG C
C
C
C    INPUT:
C              TC        R*8       TEMPERATURE DEG C
C    OUTUT:
C              FUNCTION VALUE  R*8   MBAR
C
$INCLUDE:'WRDSIZ.INC'
C
      DATA  TZERO     / 273.2 D0 /
C
      DATA  CON1  / 6.105 D0 /
      DATA  CON2  / 25.22 D0 /
      DATA  CON3  / - 5.31D0 /
C
C ------------------------------------------------------------
C
       TK  =  TC + TZERO
C
       TERM1 = CON2 * ( TC / TK )
       TERM2 = CON3 * DLOG ( TK/TZERO )
C
       PPH2O =  CON1 * DEXP ( TERM1 + TERM2 )
C
       RETURN
       END
