$TITLE:'ATROPO - ANALYTICAL TROPOSHPERE ROUTINES'
$SUBTITLE:'ATRPCE - COS(ELV) VERSION'
      FUNCTION ATRPCE ( CE )
C 
C        ATRPCE CALCULATES THE TROPOSPHERIC CORRECTION TO THE 
C     SLANT RANGE ANALYTICALLY.  ATRPCE IS CALLED USING ONLY ONE
C     ARGUMENT AND THAT ARGUMENT IS THE COS ELEVATION ANGLE 
C
C
C     VARIABLES   TYPE  DIM   MEANING
C  INPUT
C            CE    R*8    1   COS OF ELEVATION ANGLE 
C OUTPUT
C        ATRPCE    R*8        TROPOSPHERIC CORRECTION IN METERS
C
$INCLUDE:'WRDSIZ.INC'
C 
      COMMON /TROPCM / DOMD,DOMW,DSDN,DSWN
C
      REAL*8 DOMD,DOMW,DSDN,DSWN
C 
C
      RATD=1.0-(CE/DOMD)**2 
      RATW=1.0-(CE/DOMW)**2 
      DSD=DSDN/SQRT(RATD) 
      DSW=DSWN/SQRT(RATW) 
      ATRPCE=DSD+DSW
      RETURN
      END
$PAGE
$SUBTITLE:'ANLTRP - ELVATION ANGLE VERSION'
      REAL*8 FUNCTION ANLTRP ( ELV )
C 
C      ELV  = ELEVATION ANGLE IN DEGREES
C
C        ANLTRO CALCULATES THE TROPOSPHERIC CORRECTION TO THE 
C     SLANT RANGE ANALYTICALLY. 
C
C     VARIABLES   TYPE  DIM   MEANING
C  INPUT
C           ELV    R*8    1   ELEVATION ANGLE IN DEGREES
C OUTPUT
C        ANLTRP    R*8        TROPOSPHERIC CORRECTION IN METERS
C
$INCLUDE:'WRDSIZ.INC'
C 
C
      COMMON /TROPCM / DOMD,DOMW,DSDN,DSWN
C
      REAL*8 DOMD,DOMW,DSDN,DSWN
C
      REAL*8 ELV,ELVR,CE,DTR
      REAL*8 RATD,RATW,DSD,DSW
C
      DATA DTR/1.745329252E-2/
C
      ELVR = ELV * DTR
      CE = DCOS(ELVR)
      RATD=1.0-(CE/DOMD)**2 
      RATW=1.0-(CE/DOMW)**2 
      DSD=DSDN/SQRT(RATD) 
      DSW=DSWN/SQRT(RATW) 
      ANLTRP=DSD+DSW
      RETURN
      END
$PAGE
$SUBTITLE:'TRPINT - INITIALIZE/RESET TROP MODEL'
      SUBROUTINE TRPINT ( TC, PRMB, RH )
C 
C        TRPINT INITIALIZES THE CONSTANTS OF THE TROP MODEL 
C        EVALUATED BY ATRPCE AND ANLTRP.  TRPINT MUST BE CALLED
C        BEFORE THE FIRST CALL TO ATRPCE/ANLTRP AND EVERY TIME
C        THE WEATHER DATA IS TO BE CHANGED.
C
C     VARIABLE    TYPE   DIM  MEANING
C  INPUT
C           TC     R*8     1  TEMPERATURE IN DEGREES CELSIUS
C         PRMB     R*8     1  PRESSURE IN MB
C           RH     R*8     1  RELATIVE HUMIDITY IN PERCENT
C
C 
$INCLUDE:'WRDSIZ.INC'
C
      COMMON /TROPCM / DOMD,DOMW,DSDN,DSWN
C
      REAL*8 DOMD,DOMW,DSDN,DSWN
C
C 
      DATA RS/6378145./
      DATA SLW/12000./
C
      PA=PRMB/1013.25 
      TK=TC+273.
      SLD=148.98*(TK-3.96)
C 
      DSDN=2.343*PA*(TK-3.96)/TK
C 
C*************
C     THE PREVIOUS WAY OF CALCULATING DSWN WAS TO USE DSWN = RH * 
C     RHC / 100.0 WITH RHC = 0.24.  RHC IS NOT USED NOW AT ALL. 
C*************
C 
      HWET = 12 000.0 
      TKS = TK * TK 
      EKK = 0.01 * RH * EXP(-37.2465 + 0.213166 * TK - 0.256908E-3 *
     .      TKS)
      ANSW = 3.73E5 * EKK / (TK * TK) 
      DSWN = (ANSW / 5.0) * HWET * 1.0E-6 
C 
      DOMD=1.0+(.15)*SLD/RS 
      DOMW=1.0+(.15)*SLW/RS 
C
      RETURN
      END 
