$TITLE:'RI ETC AIR'
$SUBTITLE:'REFRACTIVITY AIR'
      SUBROUTINE NAIR ( TC, PMB, RH, RI )
C
C        REFRACTIVTY OF AIR
C        REF. INDEX  = 1 + 10**6 * RI
C
C
C
C    INPUT
C              TC   R*8       TEMP. DEG C
C              PMB  R*8       PRESSURE MILLI-BARS
C              RH   R*8       RELATIVE HUMIDITY
C
C    OUTPUT:
C              RI   R*8       RI=REFRACTIVITY = 1.0D6 * (n-1)
C                             CALLED 'N' IN LITERATURE
C
C      -------------------------------------------------
C      J.R. Clynch   6/30/92  NPS
C
C      From notes of K. Davidson Met.
C
C      Checked with CRC handbook on Vapor Pressure H2O
C      and a Marwin Radiosonde Raw data set
C
C       Agrees with both to .2 percent
C       -------------------------------------------------
C
C
C    MODHIST:
C              
C         7-6-02   MODIFIED TZ CONSTANT TO MATCH NPS MET. M-FILES
C
$INCLUDE:'WRDSIZ.INC'
C
C
      DATA  TZERO     / 273.155D0 /
      DATA  CAIR      / 77.6   D0 /
      DATA  C1H2O     / -5.6   D0 /
      DATA  C2H2O     / 3.75   D5  /
C
C        -------------------------------------------------
C
      TK  = TC + TZERO
C
C           GET PARTIAL PRESSURE WATER = RH*VAPOR PRESSURE
C
      EH2O = 0.0D0
      IF ( RH.GT.0.0D0 ) EH2O  = RH * PPH2O ( TC ) / 100.0D0
C
      RI  =  CAIR * (PMB/TK) - C1H2O*(EH2O/TK) + C2H2O*(EH2O/TK/TK)
C
C
      RETURN
      END
$PAGE
$SUBTITLE:'MODIFIED REF. INDEX.'
      SUBROUTINE NMAIR ( TC, PMB, RH, HGHM, RI, RIMOD )
C
C        REFRACTIVTY OF AIR
C        REF. INDEX  = 1 + 10**6 * RI
C
C
C
C    INPUT
C              TC   R*8       TEMP. DEG C
C              PMB  R*8       PRESSURE MILLI-BARS
C              RH   R*8       RELATIVE HUMIDITY
C              HGHM R*8       HEIGHT IN METERS
C
C    OUTPUT:
C              RI   R*8       RI=REFRACTIVITY = 1.0D6 * (n-1)
C                             CALLED 'N' IN LITERATURE
C              RIMOD R*8      MODIFIED N,  M=N+157*Hkm
C                             - TAKES NORMAL ATM. VERT. GRADIENT OUT
C                             - "FLATTENS EARTH"
C
C
C    MODHIST:
C              
C         7-6-02   CODED
C
$INCLUDE:'WRDSIZ.INC'
C
C              ------------------------------------------
C
C
      CALL NAIR ( TC, PMB, RH, RI )
C
      RIMOD  =  RI + 157.D0 * HGHM/1000.0D0
C
      RETURN
      END
$PAGE
$SUBTITLE:'WATER PARTIAL PRES.'
      FUNCTION  PPH2O ( TC )
C
C         COMPUTE SATURATED PARTIAL PRESSURE OF WATER VAPOR
C         AS A FUNCTION OF  TEMPERATURE
C
C         _Atm. Sci_ by Wallace + Hobbs via Mary Jordon M.file
C
$INCLUDE:'WRDSIZ.INC'
C
C    MODHIST:
C            7-2-02   JRC. 
C
      EXPON  = 17.26939D0 * ( TC)/(TC + 237.3D0)
      ES     = 6.1078D0 * EXP ( EXPON )
C
C
      PPH2O  = ES
C
      RETURN
      END
$PAGE
$SUBTITLE:'POTENTIAL TEMP'
      SUBROUTINE  POTTMP ( TC, PMB, THETA )
C
C         COMPUTE THE POTENTIAL TEMPERATURE - AIR
C              ASSUMES MOLECULAR WEIGHT AIR
C
C    INPUT:
C         TC        R*8       TEMPERATURE DEG C
C         PMB       R*8       PRESSURE, MBAR
C    OUTPUT:
C         THETA     R*8       POTENTIAL TEMP, THETA
C
C    MODHIST
C         7-6-02    JRC CODED // MATCH MET-MFILES CONSTANTS
C
$INCLUDE:'WRDSIZ.INC'
C
C
      DATA   PNOR    /1000.0D0 /
      DATA   RSTAR   / 287.0D0 /
      DATA   CPAIR   / 1.004D3 /
      DATA   TZ      /273.115D0/
C
C         CP AND RSTAR HAVE CANCELLING 1.0D3 ADJUSTMENTS IN UNITS
C
C         ---------------------------------
C
      TK  = TC + TZ
C
      THETA  = TK * (PNOR/PMB) * RSTAR/CPAIR
C
      RETURN
      END
$PAGE
$SUBTITLE:'SPEC. HUMIDITY'
      SUBROUTINE   SPCHUM ( TC,PMB,RH,Q,W )
C
C         COMPUTE SPECIFIC HUMIDITY IN g/Kg OF WATER
C         AND MIXING RATION
C
C    MODHIST:
C
C         7-6-02    JRC CODED TO MATCH NPS MET MFILES
C
C
C
C    INPUT:
C         TC        R*8       TEMPERATURE DEG-C
C         PMB       R*8       PRESSURE MBAR
C         RH        R*8       RELATIVE HUMIDTY - %
C    OUTPUT:
C         Q         R*8       SPECIFIC HUMIDITY g/Kg
C         W         R*8       MIXING RATION     (Kg/Kg)
C
C
C
C
$INCLUDE:'WRDSIZ.INC'
C
C
C         ----------------------------------------------------
C
      ESH2O  = PPH2O ( TC )
      EE     = RH*ESH2O/100.0D0
C
      W      = 0.622D0  * (EE/(PMB - EE) )
      Q      = 1000.0D0 * W/(1.0D0 + W )
C
      RETURN
      END
