$TITLE:'WATER VAPOR RTNS'
$SUBTITLE:'PARTIAL PRES. H2O'
      FUNCTION  PPH2O ( TC )
C
C         COMPUTE SATURATED PARTIAL PRESSURE OF WATER VAPOR
C         AS A FUNCTION OF  TEMPERATURE
C
C         _Atm. Sci_ by Wallace + Hobbs via Mary Jordon M.file
C
$INCLUDE:'WRDSIZ.INC'
C
C    MODHIST:
C            7-2-02   JRC. 
C
      EXPON  = 17.26939D0 * ( TC)/(TC + 237.3D0)
      ES     = 6.1078D0 * EXP ( EXPON )
C
C
      PPH2O  = ES
C
      RETURN
      END
$PAGE
$SUBTITLE:'DEW POINT'
      FUNCTION  DEWPT ( TC, RH )
C
C         COMPUTE THE DEW POINT FROM TEMP. AND REL. HUM.
C         JUST TEMPERATURE WHERE CURRENT VAPOR PRESSURE IS SATURATED
C
C         INPUT:
C                   TC   R*8       TEMP. DEG C
C                   RH   R*8       REL. HUMIDITY PERCENT
C         OUTPUT:
C                   FUNCTION IS DEW POINT IN DEG C
C
C         ESSENTIALLY THE INVERSE OF PPH2O 
C         AFTER FIND VAPOR PRES. H2O
C
C    MODHIST
C         JRC   8-22-02  CODED
C
C
$INCLUDE:'WRDSIZ.INC'
C
C    -------------------------------------------------------------
C
      ES    =  PPH2O ( TC )
      E     =  RH * ES / 100.0D0
C
      TZ    = 237.3D0
C
      TDP   = -100.0D0
C
      IF ( E .GT. 0.D0 ) THEN
          VALLOG = ALOG ( E / 6.1078D0 )
          TDP    = TZ*VALLOG / ( 17.26939D0 - VALLOG )
      ENDIF
C
      DEWPT  = TDP
C
      RETURN
      END
$PAGE
$SUBTITLE:'TWET, TDRY TO RH'
      SUBROUTINE    TDW2RH ( TDRY, TWET, RH )
C
C         COMPUTE THE RELATIVE HUMIDITY FROM WET AND DRY TEMPS
C         -- ASSUMES TWET = DEW POINT
C
C    INPUT:
C              TDRY      R*8       DRY / AMBIENT TEMPERATURE DEG C
C              TWET      R*8       WET BULB TEMP  DEG C
C    OUTPUT:
C              RH        R*8       REL HUMIDITY PERCENT
C
C    MODHIST:
C         8-22-02        JRC CODED
C
$INCLUDE:'WRDSIZ.INC'
C
C    -----------------------------------------------------------
C
      REL  = 100.0D0
C
      IF ( TWET.LE.TDRY ) THEN
          ES   =  PPH2O ( TDRY )
          E    =  PPH2O ( TWET )
          REL  =  100.0D0 * E / ES
      ENDIF
C
      RH   =  REL
C
      RETURN
      END
